# Routerling

<img src="https://img.shields.io/badge/coverage-92%25-green" />

Build web applications and enterprise microservices with the _**simplest**_ and possibly the fastest or one of the _**fastest**_ web microframeworks for python.

[Go To Docs](https://rayattack.github.io/routerling)
